### GeneSeekr

#### [Read the Docs](https://OLC-Bioinformatics.github.io/GeneSeekr)

[![Build Status](https://travis-ci.org/OLC-Bioinformatics/GeneSeekr.svg?branch=dev)](https://travis-ci.org/OLC-Bioinformatics/GeneSeekr)
